@@ -98,7 +98,7 @@ typedef struct {
 
 /*static GSList *connections;*/
 
-GstTool *tool;
+extern GstTool *tool;
 
 static gboolean
 connection_xml_get_boolean (xmlNode *node, gchar *elem)
@@ -1463,6 +1463,7 @@ connection_new_from_node (xmlNode *node, gboolean add_to_list)
 		break;
 	case GST_CONNECTION_WLAN:
 		cxn->essid = gst_xml_get_child_content (node, "essid");
+		cxn->key = gst_xml_get_child_content (node, "key");
 		break;
 	default:
 		break;
@@ -1502,6 +1503,7 @@ connection_free (GstConnection *cxn)
 	g_free (cxn->gateway);
 
 	g_free (cxn->essid);
+	g_free (cxn->key);
 
 	g_free (cxn->phone_number);
 	g_free (cxn->external_line);
@@ -1671,6 +1673,7 @@ static void
 empty_wlan (GstConnection *cxn)
 {
 	GET_STR ("wlan_", essid);
+	GET_STR ("wlan_", key);
 }
 
 static void
@@ -1879,6 +1882,7 @@ static void
 fill_wlan (GstConnection *cxn)
 {
 	SET_STR ("wlan_", essid);
+	SET_STR ("wlan_", key);
 }
 
 static void
@@ -1938,8 +1942,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 	fill_general (cxn);
 
 	if (cxn->type == GST_CONNECTION_PPP) {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/ppp.png");
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), TRUE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 12);
 
@@ -1957,8 +1959,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
 	} else if (cxn->type == GST_CONNECTION_WLAN) {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/wavelan-48.png");
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
@@ -1973,8 +1973,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 		fill_ip (cxn);
 		fill_wlan (cxn);
 	} else if (cxn->type == GST_CONNECTION_ETH) {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/connection-ethernet.png");
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
@@ -1988,8 +1986,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 
 		fill_ip (cxn);
 	} else if (cxn->type == GST_CONNECTION_PLIP) {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/plip-48.png");
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
@@ -2003,8 +1999,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 
 		fill_ptp (cxn);
 	} else if (cxn->type == GST_CONNECTION_IRLAN) {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/irda-48.png");
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
@@ -2018,9 +2012,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 
 		fill_ip (cxn);
 	} else {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/network.png");
-
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
@@ -2231,8 +2222,10 @@ connection_save_to_node (GstConnection *cxn, xmlNode *root)
 		connection_xml_save_str_to_node (node, "remote_address", cxn->remote_address);
 
 	/* Wireless */
-	if (cxn->type == GST_CONNECTION_WLAN)
+	if (cxn->type == GST_CONNECTION_WLAN) {
 		connection_xml_save_str_to_node (node, "essid", cxn->essid);
+		connection_xml_save_str_to_node (node, "key", cxn->key);
+	}
 }
 
 gboolean
