@@ -119,42 +119,6 @@ user_value_group_peek (xmlNodePtr user_node)
 	return buf;
 }
 
-GList*
-user_get_groups (xmlNodePtr user_node)
-{
-	xmlNodePtr group_node, g, group_users;
-	gchar *user_name, *buf;
-	GList *grouplist = NULL;
-
-	g_return_val_if_fail (user_node != NULL, NULL);
-
-	group_node = get_corresp_field (user_node);
-	user_name = user_value_login (user_node);
-
-	if (!user_name)
-		return NULL;
-
-	for (g = gst_xml_element_find_first (group_node, "group"); g;
-	     g = gst_xml_element_find_next (g, "group")) {
-		group_users = gst_xml_element_find_first (g, "users");
-		for (group_users = gst_xml_element_find_first (group_users, "user");
-		     group_users;
-		     group_users = gst_xml_element_find_next (group_users, "user")) {
-			buf = gst_xml_element_get_content (group_users);
-			if (!buf)
-				continue;
-
-			if (!strcmp (user_name, buf))
-				grouplist = g_list_insert_sorted (grouplist, group_value_name (g), my_strcmp);
-			
-			g_free (buf);
-		}
-	}
-
-	g_free (user_name);
-	return grouplist;
-}
-
 void
 del_user_groups (xmlNodePtr user_node)
 {
@@ -428,7 +392,7 @@ static void
 user_add_extra_groups (GList *groups_list, const gchar *username)
 {
 	xmlNodePtr groupdb = gst_xml_element_find_first (gst_xml_doc_get_root (tool->config), "groupdb");
-	xmlNodePtr node, users;
+	xmlNodePtr node, users, user_node;
 	gchar *groupname;
 	GList *list;
 	gboolean found;
@@ -450,7 +414,8 @@ user_add_extra_groups (GList *groups_list, const gchar *username)
 		
 		if (found) {
 			users = gst_xml_element_find_first (node, "users");
-			gst_xml_element_add_with_content (users, "user", (gchar *) username);
+			user_node = gst_xml_element_add (users, "user");
+			gst_xml_element_set_content (user_node, (gchar *) username);
 			g_list_remove (groups_list, groupname);
 		}
 	}
@@ -562,8 +527,9 @@ node_exists (xmlNodePtr node, const gchar *name, const gchar *val)
 GList *
 get_group_users (xmlNodePtr group_node)
 {
-	GList *userlist = NULL;
-	xmlNodePtr node, u;
+	GList      *userlist = NULL;
+	xmlNodePtr  node, u;
+	gchar      *user;
 
 	g_return_val_if_fail (group_node != NULL, NULL);
 
@@ -572,7 +538,8 @@ get_group_users (xmlNodePtr group_node)
 		return NULL;
 
 	for (u = gst_xml_element_find_first (node, "user"); u; u = gst_xml_element_find_next (u, "user")) {
-		userlist = g_list_insert_sorted (userlist, gst_xml_element_get_content (u), my_strcmp);
+		user = gst_xml_element_get_content (u);
+		userlist = g_list_insert_sorted (userlist, user, my_strcmp);
 	}
 
 	return userlist;
@@ -598,10 +565,7 @@ get_list_from_node (gchar *field, gint table)
 	
 
 	for (u = gst_xml_element_find_first (n, key); u != NULL; u = gst_xml_element_find_next (u, key))
-	{
-		if (check_node_visibility (u))
-			list = g_list_insert_sorted (list, gst_xml_get_child_content (u, field), my_strcmp);
-	}
+		list = g_list_insert_sorted (list, gst_xml_get_child_content (u, field), my_strcmp);
 
 	return list;
 }
